//
// Swiftfin is subject to the terms of the Mozilla Public
// License, v2.0. If a copy of the MPL was not distributed with this
// file, you can obtain one at https://mozilla.org/MPL/2.0/.
//
// Copyright (c) 2022 Jellyfin & Jellyfin Contributors
//

import Foundation

public extension Collection {

	/// SwifterSwift: Safe protects the array from out of bounds by use of optional.
	///
	///        let arr = [1, 2, 3, 4, 5]
	///        arr[safe: 1] -> 2
	///        arr[safe: 10] -> nil
	///
	/// - Parameter index: index of element to access element.
	subscript(safe index: Index) -> Element? {
		indices.contains(index) ? self[index] : nil
	}
}
